# Unit Tests

The scope of the unit tests is to test separate, distinct features of MAUS: units.

The data they rely on are mostly made up "artificial" data or real data stripped down to the essential part
relevant to the code under test.

These test data are part of the public MAUS repository and thus publicly available.
